@@ -201,15 +201,15 @@ class OAuth(object):
         kwargs['method'] = 'DELETE'
         return self.request(*args, **kwargs)
 
-    def make_client(self, request, token=None, secret=None):
+    def make_client(self, request=None, token=None, secret=None):
         """Creates a new `oauth2` Client object with the token attached.
         Usually you don't have to do that but use the :meth:`request`
         method instead.
         """
         return oauth2.Client(self._consumer, self.get_request_token(request, token, secret))
 
-    def request(self, request, url, data="", headers=None, format='urlencoded',
-                method='GET', content_type=None, token=None, secret=None):
+    def request(self, url, data="", headers=None, format='urlencoded',
+                method='GET', content_type=None, token=None, secret=None, request=None):
         """Sends a request to the remote server with OAuth tokens attached.
         The `url` is joined with :attr:`base_url` if the URL is relative.
 
@@ -285,6 +285,7 @@ class OAuth(object):
             rv = (token, secret)
         else:
             assert self.tokengetter_func is not None, 'missing tokengetter function'
+            assert request is not None, 'missing request (needed when token+secret are not known yet)'
             # Don't pass the token if the token is None to support old
             # tokengetter functions.
             rv = self.tokengetter_func(request, token)
